From 4e2dcf4015d952f8311a019f06fc85765089886b Mon Sep 17 00:00:00 2001
From: Peter Kjellerstedt <pkj@axis.com>
Date: Thu, 3 Jul 2008 14:44:51 +0000
Subject: gst/rtpmanager/: Corrected a typo (interpollate -> interpolate).

Original commit message from CVS:
* ChangeLog:
* gst/rtpmanager/gstrtpjitterbuffer.c: (gst_rtp_jitter_buffer_loop):
* gst/rtpmanager/rtpsource.c: (rtp_source_get_new_sr):
Corrected a typo (interpollate -> interpolate).
---
 gst/rtpmanager/rtpsource.c | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

(limited to 'gst/rtpmanager/rtpsource.c')

diff --git a/gst/rtpmanager/rtpsource.c b/gst/rtpmanager/rtpsource.c
index 50170d10..4c01a7ad 100644
--- a/gst/rtpmanager/rtpsource.c
+++ b/gst/rtpmanager/rtpsource.c
@@ -1184,7 +1184,7 @@ rtp_source_get_new_sr (RTPSource * src, guint64 ntpnstime,
 
   g_return_val_if_fail (RTP_IS_SOURCE (src), FALSE);
 
   /* use the sync params to interpollate the date->time member to rtptime. We
    * use the last sent timestamp and rtptime as reference points. We assume
    * that the slope of the rtptime vs timestamp curve is 1, which is certainly
    * sufficient for the frequency at which we report SR and the rate we send
@@ -1211,7 +1211,7 @@ rtp_source_get_new_sr (RTPSource * src, guint64 ntpnstime,
       t_rtp -= gst_util_uint64_scale_int (diff, src->clock_rate, GST_SECOND);
     }
   } else {
-    GST_WARNING ("no clock-rate, cannot interpollate rtp time");
+    GST_WARNING ("no clock-rate, cannot interpolate rtp time");
   }
 
   /* convert the NTP time in nanoseconds to 32.32 fixed point */
@@ -1184,7 +1184,7 @@ rtp_source_get_new_sr (RTPSource * src, guint64 ntpnstime,
   g_return_val_if_fail (RTP_IS_SOURCE (src), FALSE);
 
-  /* use the sync params to interpollate the date->time member to rtptime. We
+  /* use the sync params to interpolate the date->time member to rtptime. We
    * use the last sent timestamp and rtptime as reference points. We assume
    * that the slope of the rtptime vs timestamp curve is 1, which is certainly
-- 
cgit v1.2.1